@@ -191,7 +191,7 @@ class TrajectopyGUI(QtWidgets.QMainWindow):
         plot_settings_action.setVisible(self.plot_manager.plot_backend == PlotBackend.MPL)
         menubar.addAction(plot_settings_action)
 
-        plot_backend_menu = QtWidgets.QMenu("Plotting", parent=self)
+        plot_backend_menu = QtWidgets.QMenu("Plotting Backend", parent=self)
         self.plotly_action = QAction("Plotly (HTML)", parent=self, checkable=True)
         self.matplotlib_action = QAction("Matplotlib", parent=self, checkable=True)
         self.matplotlib_action.setChecked(self.plot_manager.plot_backend == PlotBackend.MPL)
@@ -480,7 +480,7 @@ class TrajectopyGUI(QtWidgets.QMainWindow):
 
     def retranslateUi(self):
         _translate = QtCore.QCoreApplication.translate
-        self.setWindowTitle(_translate("MainWindow", "Trajectopy - Trajectory Evaluation in Python"))
+        self.setWindowTitle(_translate("MainWindow", "Trajectopy"))
         self.label.setText(_translate("MainWindow", "Trajectories:"))
         self.addTrajectoryButton.setText(_translate("MainWindow", "Add"))
         self.label_2.setText(_translate("MainWindow", "Results:"))
