@@ -37,16 +37,17 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
 
     def __init__(self, parent=None) -> None:
         super().__init__(parent)
-        self.pipelines_context_menu = QtWidgets.QMenu("Pipelines")
+        self.metrics_context_menu = QtWidgets.QMenu("Metrics")
         self.comparison_context_menu = QtWidgets.QMenu("Compare With Reference")
         self.match_context_menu = QtWidgets.QMenu("Match With Reference")
+        self.other_context_menu = QtWidgets.QMenu("Other")
         self.view_context_menu = QtWidgets.QMenu("View")
         self.edit_context_menu = QtWidgets.QMenu("Edit")
         self.action_context_menu = QtWidgets.QMenu("Action")
         self.absolute_menu = QtWidgets.QMenu("Absolute", self)
         self.relative_menu = QtWidgets.QMenu("Relative", self)
-        self.least_squares_menu = QtWidgets.QMenu("Least Squares", self)
-        self.align_first_pose_menu = QtWidgets.QMenu("Align First Pose", self)
+        self.least_squares_menu = QtWidgets.QMenu("All Poses", self)
+        self.align_first_pose_menu = QtWidgets.QMenu("First Pose", self)
         self.align_with_reference_sub_menu = QtWidgets.QMenu("Align With Reference", self)
         self._selection: TrajectorySelection
 
@@ -72,9 +73,10 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
 
     def clear(self) -> None:
         super().clear()
-        self.pipelines_context_menu.clear()
+        self.metrics_context_menu.clear()
         self.comparison_context_menu.clear()
         self.match_context_menu.clear()
+        self.other_context_menu.clear()
         self.view_context_menu.clear()
         self.edit_context_menu.clear()
         self.action_context_menu.clear()
@@ -122,7 +124,7 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
         self.view_context()
         self.edit_context()
         self.action_context()
-        self.pipelines_context()
+        self.metrics_context()
 
     def edit_context(self) -> None:
         """Actions sub-context menu"""
@@ -181,24 +183,31 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
         )
         self.edit_context_menu.addAction(merge_action)
 
-        if not self.get_selection().entries[0].state.sorting_known:
-            return
+        if self.get_selection().entries[0].state.sorting_known:
+            switch_sorting_action = QAction("Switch Sorting", self)
+            switch_sorting_action.triggered.connect(
+                lambda: self.trajectory_manager_request.emit(
+                    TrajectoryManagerRequest(
+                        type=TrajectoryManagerRequestType.SWITCH_SORTING,
+                        selection=self.get_selection(),
+                    )
+                )
+            )
+            self.edit_context_menu.addAction(switch_sorting_action)
 
-        switch_sorting_action = QAction("Switch Sorting", self)
-        switch_sorting_action.triggered.connect(
-            lambda: self.trajectory_manager_request.emit(
-                TrajectoryManagerRequest(
-                    type=TrajectoryManagerRequestType.SWITCH_SORTING,
-                    selection=self.get_selection(),
+        dof_action = QAction("Reorganize DOFs", self)
+        dof_action.triggered.connect(
+            lambda: self.ui_request.emit(
+                UIRequest(
+                    type=UIRequestType.DOF_ORGANIZER,
+                    trajectory_selection=self.get_selection(),
                 )
             )
         )
-        self.edit_context_menu.addAction(switch_sorting_action)
+        self.edit_context_menu.addAction(dof_action)
 
-        if not single_selection:
-            return
-
-        self.edit_single()
+        if single_selection:
+            self.edit_single()
 
     def edit_single(self):
         rename_action = QAction("Rename", self)
@@ -251,6 +260,10 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
     def action_context(self) -> None:
         self.addMenu(self.action_context_menu)
 
+        self.action_context_menu.addMenu(self.align_context())
+        self.action_context_menu.addMenu(self.compare_context())
+        self.action_context_menu.addMenu(self.match_context())
+
         change_datum_action = QAction("Transform to EPSG", self)
         change_datum_action.triggered.connect(
             lambda: self.ui_request.emit(
@@ -262,32 +275,6 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
         )
         self.action_context_menu.addAction(change_datum_action)
 
-        self.action_context_menu.addMenu(self.align_context())
-        self.action_context_menu.addMenu(self.compare_context())
-        self.action_context_menu.addMenu(self.match_context())
-
-        sort_action = QAction("Sort Spatially", self)
-        sort_action.triggered.connect(
-            lambda: self.trajectory_manager_request.emit(
-                TrajectoryManagerRequest(
-                    type=TrajectoryManagerRequestType.SORT,
-                    selection=self.get_selection(),
-                )
-            )
-        )
-        self.action_context_menu.addAction(sort_action)
-
-        divide_into_laps_action = QAction("Divide into Laps", self)
-        divide_into_laps_action.triggered.connect(
-            lambda: self.trajectory_manager_request.emit(
-                TrajectoryManagerRequest(
-                    type=TrajectoryManagerRequestType.DIVIDE_INTO_LAPS,
-                    selection=self.get_selection(),
-                )
-            )
-        )
-        self.action_context_menu.addAction(divide_into_laps_action)
-
         approximate_action = QAction("Approximate", self)
         approximate_action.triggered.connect(
             lambda: self.trajectory_manager_request.emit(
@@ -314,16 +301,7 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
         )
         self.action_context_menu.addAction(apply_alignment_action)
 
-        average_action = QAction("Average", self)
-        average_action.triggered.connect(
-            lambda: self.trajectory_manager_request.emit(
-                TrajectoryManagerRequest(
-                    type=TrajectoryManagerRequestType.AVERAGE,
-                    selection=self.get_selection(),
-                )
-            )
-        )
-        self.action_context_menu.addAction(average_action)
+        self.action_context_menu.addMenu(self.other_context())
 
         if not self.get_selection().reference_is_set:
             return
@@ -342,6 +320,41 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
         )
         self.action_context_menu.addAction(epsg_to_ref_action)
 
+    def other_context(self) -> QtWidgets.QMenu:
+        sort_action = QAction("Sort Spatially", self)
+        sort_action.triggered.connect(
+            lambda: self.trajectory_manager_request.emit(
+                TrajectoryManagerRequest(
+                    type=TrajectoryManagerRequestType.SORT,
+                    selection=self.get_selection(),
+                )
+            )
+        )
+        self.other_context_menu.addAction(sort_action)
+
+        divide_into_laps_action = QAction("Divide into Laps", self)
+        divide_into_laps_action.triggered.connect(
+            lambda: self.trajectory_manager_request.emit(
+                TrajectoryManagerRequest(
+                    type=TrajectoryManagerRequestType.DIVIDE_INTO_LAPS,
+                    selection=self.get_selection(),
+                )
+            )
+        )
+        self.other_context_menu.addAction(divide_into_laps_action)
+
+        average_action = QAction("Average", self)
+        average_action.triggered.connect(
+            lambda: self.trajectory_manager_request.emit(
+                TrajectoryManagerRequest(
+                    type=TrajectoryManagerRequestType.AVERAGE,
+                    selection=self.get_selection(),
+                )
+            )
+        )
+        self.other_context_menu.addAction(average_action)
+        return self.other_context_menu
+
     def align_context(self) -> QtWidgets.QMenu:
         self.align_with_reference_sub_menu.setEnabled(self.get_selection().reference_is_set)
 
@@ -607,9 +620,9 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
 
         return self.match_context_menu
 
-    def pipelines_context(self) -> None:
-        self.addMenu(self.pipelines_context_menu)
-        self.pipelines_context_menu.setEnabled(self.get_selection().reference_is_set)
+    def metrics_context(self) -> None:
+        self.addMenu(self.metrics_context_menu)
+        self.metrics_context_menu.setEnabled(self.get_selection().reference_is_set)
 
         ate_action = QAction("Compute ATE", self)
         ate_action.triggered.connect(
@@ -631,5 +644,5 @@ class TrajectoryContextMenu(QtWidgets.QMenu):
             ),
         )
 
-        self.pipelines_context_menu.addAction(ate_action)
-        self.pipelines_context_menu.addAction(rpe_action)
+        self.metrics_context_menu.addAction(ate_action)
+        self.metrics_context_menu.addAction(rpe_action)
