@@ -110,6 +110,10 @@ class Trajectory:
         # pose
         self.pos = pos
         self.rot = rot
+
+        if not isinstance(tstamps, np.ndarray):
+            tstamps = np.array(tstamps) if tstamps is not None else None
+
         self.tstamps = np.arange(0, len(pos)) if tstamps is None else tstamps
 
         if speed_3d is not None and len(speed_3d) == len(self.pos):
@@ -601,7 +605,7 @@ class Trajectory:
         traj_self.apply_index(idx_self)
         return traj_self
 
-    def intersect(self, tstamps: np.ndarray, max_gap_size: float = 2.0, inplace: bool = True) -> "Trajectory":
+    def intersect(self, tstamps: np.ndarray, max_gap_size: float = 10.0, inplace: bool = True) -> "Trajectory":
         """Intersects trajectory with a given timestamp vector
 
         After intersection, the trajectory covers the same
@@ -615,7 +619,7 @@ class Trajectory:
         Args:
             tstamps (np.ndarray): Intersection timespans
             max_gap_size (float, optional): Maximum allowed gap between timespans.
-                                            If Defaults to 0.5.
+                                            If Defaults to 10.0.
             inplace (bool, optional): Perform intersection in-place.
                                       Defaults to True.
 
@@ -676,7 +680,7 @@ class Trajectory:
 
         if traj_self.rot:
             quat_filtered = traj_self.rot.as_quat()[index, :]
-            traj_self.rot = RotationSet.from_quat(quat_filtered)
+            traj_self.rot = RotationSet.from_quat(quat_filtered) if len(quat_filtered) > 0 else None
 
         traj_self.arc_lengths = traj_self.arc_lengths[index]
 
@@ -726,7 +730,7 @@ class Trajectory:
                     alignment_parameters.lever_z.value,
                 )
             else:
-                logger.error("Trajectory has no orientations. Cannot apply leverarm.")
+                logger.warning("Trajectory has no orientations. Cannot apply leverarm.")
                 euler_x, euler_y, euler_z = 0, 0, 0
                 lever_x, lever_y, lever_z = 0, 0, 0
 
@@ -826,7 +830,7 @@ class Trajectory:
             lap = trajectory.apply_index(np.arange(lap_indices[i], lap_indices[i + 1]), inplace=False)
             laps.append(lap)
 
-        return laps if not return_lap_indices else laps, lap_indices
+        return laps if (not return_lap_indices) else (laps, lap_indices)
 
     def approximate(
         self, approximation_settings: ApproximationSettings = ApproximationSettings(), inplace: bool = True
@@ -844,8 +848,8 @@ class Trajectory:
         xyz_approx = piecewise_cubic(
             function_of=self.function_of,
             values=self.xyz,
-            int_size=approximation_settings.fe_int_size,
-            min_obs=approximation_settings.fe_min_obs,
+            min_win_size=approximation_settings.position_interval_size,
+            min_obs=approximation_settings.position_min_observations,
         )
 
         traj_approx = self if inplace else self.copy()
@@ -857,7 +861,7 @@ class Trajectory:
         quat_approx = rot_average_window(
             function_of=self.function_of,
             quat=self.quat,
-            win_size=approximation_settings.rot_approx_win_size,
+            win_size=approximation_settings.rotation_window_size,
         )
         traj_approx.rot = RotationSet.from_quat(quat_approx[self.sort_switching_index, :])
 
